@@ -23,22 +23,6 @@ extern "C" {
 
 #include "audio/ffmpeg_audio_processor.h"
 
-#ifndef HAVE_AV_PACKET_UNREF
-#define av_packet_unref av_free_packet
-#endif
-
-#ifndef HAVE_AV_FRAME_ALLOC
-#define av_frame_alloc avcodec_alloc_frame
-#endif
-
-#ifndef HAVE_AV_FRAME_FREE
-#define av_frame_free avcodec_free_frame
-#endif
-
-#ifndef AV_ERROR_MAX_STRING_SIZE
-#define AV_ERROR_MAX_STRING_SIZE 128
-#endif
-
 namespace chromaprint {
 
 class FFmpegAudioReader {
@@ -114,7 +98,6 @@ private:
 
 inline FFmpegAudioReader::FFmpegAudioReader() {
 	av_log_set_level(AV_LOG_QUIET);
-	av_register_all();
 
 	av_init_packet(&m_packet);
 	m_packet.data = nullptr;
