@@ -91,18 +91,18 @@ int AudioProcessor::Load(const int16_t *input, int length)
 void AudioProcessor::Resample()
 {
 	if (!m_resample_ctx) {
-		m_consumer->Consume(m_buffer.data(), m_buffer_offset);
+		m_consumer->Consume(m_buffer.data(), int(m_buffer_offset));
 		m_buffer_offset = 0;
 		return;
 	}
 	int consumed = 0;
-	int length = av_resample(m_resample_ctx, m_resample_buffer.data(), m_buffer.data(), &consumed, m_buffer_offset, kMaxBufferSize, 1);
+	int length = av_resample(m_resample_ctx, m_resample_buffer.data(), m_buffer.data(), &consumed, int(m_buffer_offset), kMaxBufferSize, 1);
 	if (length > kMaxBufferSize) {
 		DEBUG("chromaprint::AudioProcessor::Resample() -- Resampling overwrote output buffer.");
 		length = kMaxBufferSize;
 	}
 	m_consumer->Consume(m_resample_buffer.data(), length);
-	int remaining = m_buffer_offset - consumed;
+	int remaining = int(m_buffer_offset - consumed);
 	if (remaining > 0) {
 		std::copy(m_buffer.begin() + consumed, m_buffer.begin() + m_buffer_offset, m_buffer.begin());
 	}
